==> tuia-advert-center-api-1.5.9-20180808.064513-17-sources.jar: cn/com/duiba/tuia/core/api/dto/newMaterial/NewMaterialDto.java <==
package cn.com.duiba.tuia.core.api.dto.newMaterial;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.util.Date;

/**
 * @Author:zhangmeng
 * @Date:2018-08-07
 */
public class NewMaterialDto {

    private Long id;
    private Long aeId;
    private String aeName;
    private String url;
    private String atmosphere;
    private String bgColour;
    private String interception;
    private String newTrade;
    private String bodyElement;
    private String carton;
    private Integer isPrevalent;
    private Date gmtCreate;
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAeId() {
        return aeId;
    }

    public void setAeId(Long aeId) {
        this.aeId = aeId;
    }

    public String getAeName() {
        return aeName;
    }

    public void setAeName(String aeName) {
        this.aeName = aeName;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getAtmosphere() {
        return atmosphere;
    }

    public void setAtmosphere(String atmosphere) {
        this.atmosphere = atmosphere;
    }

    public String getBgColour() {
        return bgColour;
    }

    public void setBgColour(String bgColour) {
        this.bgColour = bgColour;
    }

    public String getInterception() {
        return interception;
    }

    public void setInterception(String interception) {
        this.interception = interception;
    }

    public String getNewTrade() {
        return newTrade;
    }

    public void setNewTrade(String newTrade) {
        this.newTrade = newTrade;
    }

    public String getBodyElement() {
        return bodyElement;
    }

    public void setBodyElement(String bodyElement) {
        this.bodyElement = bodyElement;
    }

    public String getCarton() {
        return carton;
    }

    public void setCarton(String carton) {
        this.carton = carton;
    }

    public Integer getIsPrevalent() {
        return isPrevalent;
    }

    public void setIsPrevalent(Integer isPrevalent) {
        this.isPrevalent = isPrevalent;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> tuia-advert-center-api-1.5.9-20180808.111917-18-sources.jar: cn/com/duiba/tuia/core/api/dto/newMaterial/NewMaterialDto.java <==
package cn.com.duiba.tuia.core.api.dto.newMaterial;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.util.Date;

/**
 * @Author:zhangmeng
 * @Date:2018-08-07
 */
public class NewMaterialDto {

    private Long id;
    private Long aeId;
    private String aeName;
    private String url;
    private String atmosphere;
    private String bgColour;
    private String interception;
    private String newTrade;
    private String bodyElement;
    private String carton;
    private Integer isPrevalent;
    private Date gmtCreate;
    private Date gmtModified;

    //设计人  （当前操作人）
    private Long operatorId;
    private String operatorName;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAeId() {
        return aeId;
    }

    public void setAeId(Long aeId) {
        this.aeId = aeId;
    }

    public String getAeName() {
        return aeName;
    }

    public void setAeName(String aeName) {
        this.aeName = aeName;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getAtmosphere() {
        return atmosphere;
    }

    public void setAtmosphere(String atmosphere) {
        this.atmosphere = atmosphere;
    }

    public String getBgColour() {
        return bgColour;
    }

    public void setBgColour(String bgColour) {
        this.bgColour = bgColour;
    }

    public String getInterception() {
        return interception;
    }

    public void setInterception(String interception) {
        this.interception = interception;
    }

    public String getNewTrade() {
        return newTrade;
    }

    public void setNewTrade(String newTrade) {
        this.newTrade = newTrade;
    }

    public String getBodyElement() {
        return bodyElement;
    }

    public void setBodyElement(String bodyElement) {
        this.bodyElement = bodyElement;
    }

    public String getCarton() {
        return carton;
    }

    public void setCarton(String carton) {
        this.carton = carton;
    }

    public Integer getIsPrevalent() {
        return isPrevalent;
    }

    public void setIsPrevalent(Integer isPrevalent) {
        this.isPrevalent = isPrevalent;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }

    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
